(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    100012,       3119]
NotebookOptionsPosition[     92510,       2904]
NotebookOutlinePosition[     92903,       2921]
CellTagsIndexPosition[     92860,       2918]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Interpolation von Durchflussdaten", "Title"],

Cell[TextData[{
 "Numerische Berechnungen einer F\[UDoubleDot]llstandsfunktion durch \
Interpolation, Ausgleichsrechnung, ",
 StyleBox["Min-Max-Approximation",
  FontColor->RGBColor[
   0.6235294117647059, 0.6235294117647059, 0.6235294117647059]],
 " sowie Splining\n\nProf. Dr. Bernhard Zgraggen, HSR"
}], "Subtitle"],

Cell[CellGroupData[{

Cell["Einf\[UDoubleDot]hrung in dieses Notebook", "Section"],

Cell[TextData[{
 "Dieses Dokument ist ein \"selbsterkl\[ADoubleDot]rendes\" ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Notebook, das interaktiv bearbeitet werden kann (\"Hands-On\"). \
Input-Zellen k\[ODoubleDot]nnen mittels der Tastenkombination ",
 StyleBox["\[ShiftKey]\[EnterKey]",
  Background->RGBColor[1, 0, 0]],
 " (in Worten: Shift-Enter) ausgef\[UDoubleDot]hrt werden. Falls Textzellen \
geschlossen sind, so k\[ODoubleDot]nnen sie durch Klick auf das Icon \
\[FilledDownTriangle] oder auf die blaue Zellklammer rechterhand ge\
\[ODoubleDot]ffnet werden.\n\nWenn Sie in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " auf Befehle oder Begriffe stossen, die Sie nicht verstehen, so steht Ihnen \
die m\[ADoubleDot]chtige Hilfe/Doc Center zur Verf\[UDoubleDot]gung; diese \
ist interaktiv.\n\nAllf\[ADoubleDot]llige Aufgaben/\[CapitalUDoubleDot]bungen \
befinden sich am Ende des Dokuments."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Datenimport sowie Datenaufbereitung und -darstellung", "Section"],

Cell[TextData[{
 "Die Daten der Durchflussdaten sind in einer XLS-Tabelle (XLS) gegeben \
(InputData_Anschnitte.xls",
 StyleBox["). ",
  FontSlant->"Italic"],
 StyleBox["Sie werden importiert und danach die einzelnen \
Durchflussfunktionen tabelliert. Die Ausgaben k\[ODoubleDot]nnen mittels \
Semikolon unterdr\[UDoubleDot]ckt werden..",
  FontVariations->{"CompatibilityType"->0}]
}], "Text"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input"],

Cell["\<\
Die Durchflussdaten werden importiert und danach die Spalten in Listen von \
{x, y}-Koordinatenpaaren transformiert (Leerwerte \"\" werden \
gel\[ODoubleDot]scht).\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"durchflussdata", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<InputData_Anschnitte.xls\>\"", ",", " ", "\"\<XLS\>\""}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.494129296546875*^9, 3.49412929703125*^9}, {
   3.498978297265625*^9, 3.49897829903125*^9}, 3.523871546671875*^9, {
   3.559867407146286*^9, 3.559867408877889*^9}, {3.559867515145276*^9, 
   3.559867516970479*^9}, {3.5610806005279713`*^9, 3.561080604677579*^9}, {
   3.58847959121391*^9, 3.5884795925555124`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Alternative", ":", " ", 
    RowBox[{"Chebyshev", " ", 
     RowBox[{"Messargumente", ":"}]}]}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"durchflussdata", "=", 
     RowBox[{"Import", "[", 
      RowBox[{
      "\"\<InputData_AnschnitteChebyshev.xls\>\"", ",", " ", "\"\<XLS\>\""}], 
      "]"}]}], ";"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.493030217452917*^9, 3.493030269688964*^9}, 
   3.49412921559375*^9, {3.4941292995*^9, 3.494129299890625*^9}, {
   3.49412938396875*^9, 3.494129387359375*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"durchfluss", "[", "i", "]"}], "=", 
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Extract", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"durchflussdata", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "1", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", "+", "1"}], "}"}]}], "}"}]}], "]"}], "//", 
       "Transpose"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "\"\<\>\""}], "}"}]}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]], "Input"],

Cell["Im folgenden werden Listenplots erstellt.", "Text"],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"durchflussplot", "[", "i", "]"}], "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<F\[UDoubleDot]llzeit sec\>\"", ",", " ", 
         "\"\<Durchfluss \!\(\*SuperscriptBox[\(cm\), \(3\)]\)/sec\>\""}], 
        "}"}]}], ",", " ", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"\"\<Durchfluss \>\"", "<>", 
        RowBox[{"ToString", "[", "i", "]"}]}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Hue", "[", 
           RowBox[{"i", "/", "5"}], "]"}], ",", 
          RowBox[{"PointSize", "[", "0.005", "]"}]}], "}"}], "]"}]}]}], 
     "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell["\<\
Die Listenplots k\[ODoubleDot]nnen zum Beispiel gemeinsam angezeigt werden. \
Die negativen Funktionswerte (ab ca. 11 sec) waren in den Originaldaten \
(Excel) enthalten; sie wurden unver\[ADoubleDot]ndert \[UDoubleDot]bernommen.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"durchflussplot", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<F\[UDoubleDot]llkurven Anschnitte\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.494129308703125*^9, 3.494129476109375*^9, {3.49897831221875*^9, 
   3.498978314625*^9}, 3.525408937921875*^9}],

Cell[TextData[{
 "Die folgende Code-Zeile ist funktional programmiert und erzeugt summierte \
Daten. Das Funktional ",
 StyleBox["{#[[1]], Sum[#[[i]], {i, 2, 6}]}&",
  FontFamily->"Courier New"],
 " wird mittels des ",
 StyleBox["Map",
  FontFamily->"Courier New"],
 "-Operators ",
 StyleBox["/@",
  FontFamily->"Courier New"],
 " auf die einzelnen Bestandteile der Durchflussdaten angewendet."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"durchflussTotal", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2", ",", "6"}], "}"}]}], "]"}]}], "}"}], "&"}], "/@", 
    RowBox[{"durchflussdata", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"durchflussplot", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"durchflussTotal", ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"PointSize", "[", "0.005", "]"}]}]}], "]"}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", "\"\<F\[UDoubleDot]llkurven Anschnitte\>\""}], 
    ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.494129331421875*^9, 3.4941293391875*^9}, {
  3.525408923640625*^9, 3.5254089309375*^9}, {3.58847975045899*^9, 
  3.5884797524869933`*^9}}],

Cell[BoxData[
 RowBox[{"durchflussplot", "[", "5", "]"}]], "Input",
 CellChangeTimes->{{3.498978833171875*^9, 3.498978837234375*^9}, 
   3.525408947578125*^9, 3.5568459608698215`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Polynom-Interpolationen (Collocation) \[RightArrow] {",
 StyleBox["InterpolatingPolynomial",
  FontFamily->"Courier New"],
 "}"
}], "Section"],

Cell[TextData[{
 "Das \"Collocation Polynomial\" kann mittels des m\[ADoubleDot]chtigen und \
flexiblen Operators  ",
 StyleBox["InterpolatingPolynomial",
  FontFamily->"Courier New"],
 "  gefunden werden. Dieser Operator gibt ein Objekt zur\[UDoubleDot]ck, das \
mannigfache Art und Weise in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " weiter verarbeitet werden kann (Differentiation, Integration, Grafik \
usw.). Er erlaubt symbolische \"Daten\", mehrdimensionale Interpolation, \
Ableitungsvorgaben, fehlende Daten u.v.a.m."
}], "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "interpoly", "]"}], "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"interpoly", "[", "i", "]"}], "=", 
    RowBox[{"InterpolatingPolynomial", "[", 
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], ",", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "Input"],

Cell[TextData[{
 "Ein Interpolationspolynom wird in Horner-Form (s. ",
 StyleBox["HornerForm",
  FontFamily->"Courier New"],
 ") gespeichert (zwecks effizienter und numerisch eher stabiler Auswertung). \
Die mit ",
 StyleBox["Expand",
  FontFamily->"Courier New"],
 " entwickelte Form zeigt die Standardform des Polynoms (nur informativ). Das \
Strichpunkt verhindert die Ausgabe (spart Speicher und Platz bei grossen \
Ausgaben)."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"interpoly", "[", "5", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.49412943284375*^9, 3.49412944565625*^9}, {
  3.5568459864292836`*^9, 3.556845989771475*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"interpoly", "[", "5", "]"}], "//", "Expand"}], ";"}]], "Input",
 CellChangeTimes->{{3.494129425828125*^9, 3.494129449484375*^9}, {
  3.523871627015625*^9, 3.523871630125*^9}}],

Cell["\<\
Der folgende kombinierte Plot zeigt den eingeschr\[ADoubleDot]nkten Nutzen \
der Polynom-Interpolation bei relativ grossen Datenmengen. Das \
Schwingverhalten ist stark und deshalb schwankt der Fehler in einer grossen \
Bandbreite. Die Polynom-Interpolation f\[UDoubleDot]hrt zu hochgradigen \
Polynomen (diese divergieren absolut immer gegen \[Infinity], wenn x \
\[RightArrow] \[PlusMinus]\[Infinity], wodurch sie auch f\[UDoubleDot]r \
Extrapolationen ungeeignet sind).\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"interpoly", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1.7818", ",", "11.14"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "600"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "i", "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4930302870801454`*^9, 3.493030287517659*^9}, 
   3.494129368046875*^9, 3.494129481328125*^9, 3.523871582390625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"interpoly", "=", 
   RowBox[{"InterpolatingPolynomial", "[", 
    RowBox[{"durchflussTotal", ",", "x"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"interpoly", "//", "Expand"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5238715995625*^9, 3.52387160253125*^9}}],

Cell["\<\
In \[ADoubleDot]hnlicher Art werden auch die summierten Durchflussdaten \
interpoliert und die Resultate grafisch dargestellt.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"durchflussplot", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"durchflussTotal", ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"PointSize", "[", "0.005", "]"}]}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{"interpoly", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1.7818", ",", "11.14"}], "}"}]}], "]"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<F\[UDoubleDot]llkurven Anschnitte und F\[UDoubleDot]llstand\>\""}], 
   ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<F\[UDoubleDot]llzeit sec\>\"", ",", " ", 
      "\"\<\!\(\*SuperscriptBox[\(cm\), \(3\)]\)/sec bzw. \
\!\(\*SuperscriptBox[\(cm\), \(3\)]\)\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.52387160628125*^9, 3.5238716101875*^9}, 
   3.5238716416875*^9}],

Cell[CellGroupData[{

Cell["\<\
*Integrationsversuch mit Polynom-Interpolation (Gesamtf\[UDoubleDot]llstand) \
\>", "Subsection",
 CellChangeTimes->{{3.5238717483125*^9, 3.5238717521875*^9}},
 FontColor->GrayLevel[0.5]],

Cell[TextData[{
 "Das Integral einer Durchflussfunktion ergibt theoretisch die \
F\[UDoubleDot]llstandsfunktion (bis auf additive Verschiebung: Zum Zeitpunkt \
x = 1.7818 ist der F\[UDoubleDot]llstand jeweils 0). Der Operator ",
 StyleBox["/.",
  FontFamily->"Courier New"],
 " ist der in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " wichtige Ersetzungsoperator (",
 StyleBox["ReplaceAll",
  FontFamily->"Courier New"],
 "). Das Verwenden der ",
 StyleBox["HornerForm",
  FontFamily->"Courier New"],
 " verbessert die numerische Auswertung hochgradiger Polynome signifikant."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fillpoly1", "[", "i", "]"}], "=", 
     RowBox[{"HornerForm", "@", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"interpoly", "[", "i", "]"}], ",", "x"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fillpoly", "[", "i", "]"}], "=", 
      RowBox[{
       RowBox[{"fillpoly1", "[", "i", "]"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fillpoly1", "[", "i", "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"x", "\[Rule]", "1.7818"}], "}"}]}], ")"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ";"}], 
  "  "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Normierung", " ", "so"}], ",", " ", 
    RowBox[{
     RowBox[{"dass", " ", "der", " ", "Wert", " ", "bei", " ", "x"}], " ", 
     "=", " ", 
     RowBox[{"1.7818", " ", "Null", " ", 
      RowBox[{"wird", "."}]}]}]}], " ", "*)"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fill", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"fillpoly", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"durchflussplot", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{"fill", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "12"}], "}"}]}], "]"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<F\[UDoubleDot]llkurven Anschnitte und F\[UDoubleDot]llstand\>\""}], 
   ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<F\[UDoubleDot]llzeit sec\>\"", ",", " ", 
      "\"\<\!\(\*SuperscriptBox[\(cm\), \(3\)]\)/sec bzw. \
\!\(\*SuperscriptBox[\(cm\), \(3\)]\)\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.5568460465797243`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["*Datenreduktion (Provisorisch)", "Subsection",
 CellChangeTimes->{3.5238717540625*^9},
 FontColor->GrayLevel[0.5]],

Cell["\<\
Durch folgende Code-Zeilen werden Daten generisch ausgespart (reduziert). Nat\
\[UDoubleDot]rlich w\[ADoubleDot]re es besser, sorgf\[ADoubleDot]ltiger Daten \
auszusparen (bspw. Ausreisser mit erster Priorit\[ADoubleDot]t zu \
eliminieren) bzw. die Daten auszugl\[ADoubleDot]tten. Weil es \
Approximationsverfahren gibt, die das Schwingproblem relativ effizient und \
elegant l\[ODoubleDot]sen werden, wird hier auf eine Ausarbeitung der \
Datenreduktion verzichtet.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"step", "=", 
    RowBox[{"{", 
     RowBox[{"32", ",", "16", ",", "16", ",", "16", ",", "16"}], "}"}]}], 
   ";"}], " ", 
  RowBox[{"(*", " ", "Schrittweiten", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"durchflussRed", "[", "i", "]"}], "=", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"durchfluss", "[", "i", "]"}], "]"}], ",", 
        RowBox[{"step", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "Input"],

Cell["\<\
Die Interpolationsfehler an ausgesparten Datenpunkten werden kompensiert \
durch ein verbessertes \"Gesamtbild\". Die Frage ist, was das heisst, und mit \
welchem Mass die Abweichung gemessen wird.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "interpoly", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"interpoly", "[", "i", "]"}], "=", 
    RowBox[{"InterpolatingPolynomial", "[", 
     RowBox[{
      RowBox[{"durchflussRed", "[", "i", "]"}], ",", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5568461499546366`*^9, 3.556846155518955*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"interpoly", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "200"}], ",", "600"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "i", "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{3.5568461591101604`*^9}],

Cell["\<\
Die numerische Berechnung einer F\[UDoubleDot]llstandsfunktion durch \
Integration und Summierung des letzten Abschnitts kann nun erneut und mit \
leicht besserem Resultat ausgef\[UDoubleDot]hrt werden.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Splines \[RightArrow] {",
 StyleBox["Interpolation",
  FontFamily->"Courier New"],
 "}"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
 "Piecewise Spline-",
 StyleBox["Interpolation",
  FontFamily->"Courier New"],
 " und Integration"
}], "Subsection"],

Cell[TextData[{
 "Spline of order 3 (cubic spline) with appropriate settings for the options ",
 StyleBox["InterpolationOrder",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Method",
  FontFamily->"Courier New"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses a generic spline method called B-Splines (Basis splines) which does \
not consider constraints at the boundaries (like the natural spline). \
B-Splines use a cleverly devised set of basis functions in order to simplify \
the computation of the spline formulas and in order to improve the \
algorithmic treatment."
}], "Text"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"splinepoly", "[", "i", "]"}], "=", 
    RowBox[{"Interpolation", "[", 
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.496549474421875*^9, 3.496549486953125*^9}}],

Cell[TextData[{
 "The results are of the type ",
 StyleBox["InterpolationFunction",
  FontFamily->"Courier New"],
 ". This is a functional object fully integrated into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "s operations with functions. Postfix ",
 StyleBox["//InputForm",
  FontFamily->"Courier New"],
 " if internal structure of such an object has to be considered."
}], "Text"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"splinepoly", "[", "5", "]"}], "[", "x", "]"}], ",", "x"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.496549449234375*^9, 3.49654945403125*^9}, {
  3.496549627734375*^9, 3.496549627953125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"splinepoly", "[", "5", "]"}], "//", "InputForm"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"splinepoly", "[", "i", "]"}], "[", "x", "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1.7818", ",", "11.7478"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "i", "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.49654949403125*^9, 3.4965495186875*^9}, {
   3.49654955315625*^9, 3.496549564640625*^9}, 3.496549766296875*^9, 
   3.5585893673645477`*^9}],

Cell["\<\
The accumulated flow datas are approximated by integration of the piecewise \
interpolating functions:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"splinepoly", "[", "i", "]"}], "[", "x", "]"}], ",", "x"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"splinepolyacc", "[", "i", "]"}], "=", 
    RowBox[{"(", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"splinepoly", "[", "i", "]"}], "[", "x", "]"}], ",", "x"}], 
      "]"}], ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell["\<\
Evaluation of the interpolating functions outside the range of data yields \
warnings.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"splinepolyacc", "[", "i", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1.7818", ",", "11.14"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Hue", "[", 
      RowBox[{"i", "/", "5"}], "]"}]}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{3.4965497715*^9, 3.523871689578125*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"splinepolyacc", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1.7818", ",", "11.7478"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Hue", "[", 
       RowBox[{"i", "/", "5"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.496549677328125*^9, 3.49654967934375*^9}, 
   3.496549774140625*^9, 3.52387169265625*^9}],

Cell[TextData[{
 "The next ",
 StyleBox["GraphicsGrid",
  FontFamily->"Courier New"],
 " shows all flow data together with accumulated (integrated) data."
}], "Text"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"durchflussplot", "[", "i", "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"splinepoly", "[", "i", "]"}], "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1.7818", ",", "11.7478"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Gray", ",", "Thin"}], "}"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"splinepolyacc", "[", "i", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1.7818", ",", "11.7478"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"Hue", "[", 
           RowBox[{"i", "/", "5"}], "]"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<F\[UDoubleDot]llstand \>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<F\[UDoubleDot]llzeit sec\>\"", ",", " ", 
            "\"\<\!\(\*SuperscriptBox[\(cm\), \(3\)]\)\>\""}], "}"}]}]}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.496549691140625*^9, 3.4965496931875*^9}, 
   3.49654977690625*^9, 3.523871697265625*^9, {3.5585893471781125`*^9, 
   3.5585893476617136`*^9}, {3.5585893968798*^9, 3.558589427003453*^9}, {
   3.558589540400052*^9, 3.5585895462812624`*^9}, {3.558589581318924*^9, 
   3.5585895845637293`*^9}, {3.5585896397410264`*^9, 3.5585896649506707`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Die Tridiagonalmatrix (natural spline)", "Subsection"],

Cell[TextData[{
 "The symmetric Tridiagonalmatrix for the coefficients ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[",
 StyleBox["i",
  FontSlant->"Italic"],
 "] of the quadratic terms ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", 
       RowBox[{"x", "[", "i", "]"}]}], ")"}], "2"]}], TraditionalForm]]],
 "   (i = 1, 2 \[Ellipsis] N-1) mit ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[",
 StyleBox["0",
  FontSlant->"Italic"],
 "]==0 and ",
 StyleBox["c",
  FontSlant->"Italic"],
 "[",
 StyleBox["N",
  FontSlant->"Italic"],
 "]==0 is the following one."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "i", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"durchfluss", "[", "i", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"k", "+", "1"}], ",", "1"}], "]"}], "]"}], "-", 
      RowBox[{
       RowBox[{"durchfluss", "[", "i", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"k", ",", "1"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"durchfluss", "[", "i", "]"}], "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SparseArray", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"k_", ",", "k_"}], "}"}], "\[RuleDelayed]", 
         RowBox[{"2", 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"h", "[", "i", "]"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}], "+", 
            RowBox[{
             RowBox[{"h", "[", "i", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"k", "+", "1"}], "]"}], "]"}]}], ")"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"k_", ",", "l_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"k", "-", "l"}], "]"}], "\[Equal]", "1"}]}], 
         "\[RuleDelayed]", 
         RowBox[{
          RowBox[{"h", "[", "i", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"Max", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"k", "+", "1"}], ",", 
              RowBox[{"l", "+", "1"}]}], "}"}], "]"}], "]"}], "]"}]}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "n"}], "}"}]}], "]"}], "//", "MatrixForm"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "\"\<n\>\""}], "}"}], ",", "1", ",", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"durchfluss", "[", "i", "]"}], "]"}], "-", "2"}], ",", "1", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.49654983103125*^9, 3.49654984778125*^9}}],

Cell[BoxData[""], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["*Ausgleichsspline und Integration (Experimental)",
 FontColor->RGBColor[
  0.43137254901960786`, 0.43137254901960786`, 
   0.43137254901960786`]]], "Subsection",
 CellChangeTimes->{3.52387176325*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "i", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"durchfluss", "[", "i", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "i", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"k", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"durchfluss", "[", "i", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"Length", "[", 
    RowBox[{"durchfluss", "[", "i", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"n", "=", "10"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"constraints", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", 
              RowBox[{"k", "-", "1"}], "]"}], "+", 
             RowBox[{
              RowBox[{"b", "[", 
               RowBox[{"k", "-", "1"}], "]"}], 
              RowBox[{"(", 
               RowBox[{"x", "-", 
                RowBox[{
                 RowBox[{"x", "[", "i", "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"c", "[", 
               RowBox[{"k", "-", "1"}], "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{
                  RowBox[{"x", "[", "i", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}], "2"]}], 
             "+", 
             RowBox[{
              RowBox[{"d", "[", 
               RowBox[{"k", "-", "1"}], "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{
                  RowBox[{"x", "[", "i", "]"}], "[", 
                  RowBox[{"[", 
                   RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}], "3"]}]}], 
            ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", "[", "k", "]"}], "+", 
             RowBox[{
              RowBox[{"b", "[", "k", "]"}], 
              RowBox[{"(", 
               RowBox[{"x", "-", 
                RowBox[{
                 RowBox[{"x", "[", "i", "]"}], "[", 
                 RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"c", "[", "k", "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{
                  RowBox[{"x", "[", "i", "]"}], "[", 
                  RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"d", "[", "k", "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{
                  RowBox[{"x", "[", "i", "]"}], "[", 
                  RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", 
                RowBox[{"k", "-", "1"}], "]"}], "+", 
               RowBox[{
                RowBox[{"b", "[", 
                 RowBox[{"k", "-", "1"}], "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", 
                  RowBox[{
                   RowBox[{"x", "[", "i", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"c", "[", 
                 RowBox[{"k", "-", "1"}], "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}], "2"]}], 
               "+", 
               RowBox[{
                RowBox[{"d", "[", 
                 RowBox[{"k", "-", "1"}], "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}], "3"]}]}], 
              ",", "x"}], "]"}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", "k", "]"}], "+", 
               RowBox[{
                RowBox[{"b", "[", "k", "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", 
                  RowBox[{
                   RowBox[{"x", "[", "i", "]"}], "[", 
                   RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"c", "[", "k", "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"d", "[", "k", "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}], ",", 
              "x"}], "]"}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", 
                RowBox[{"k", "-", "1"}], "]"}], "+", 
               RowBox[{
                RowBox[{"b", "[", 
                 RowBox[{"k", "-", "1"}], "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", 
                  RowBox[{
                   RowBox[{"x", "[", "i", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"c", "[", 
                 RowBox[{"k", "-", "1"}], "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}], "2"]}], 
               "+", 
               RowBox[{
                RowBox[{"d", "[", 
                 RowBox[{"k", "-", "1"}], "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"k", "-", "1"}], "]"}], "]"}]}], ")"}], "3"]}]}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "2"}], "}"}]}], "]"}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"a", "[", "k", "]"}], "+", 
               RowBox[{
                RowBox[{"b", "[", "k", "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", 
                  RowBox[{
                   RowBox[{"x", "[", "i", "]"}], "[", 
                   RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"c", "[", "k", "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"d", "[", "k", "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "2"}], "}"}]}], "]"}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}]}]}], 
       "\[IndentingNewLine]", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "2", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"objective", "[", "lambda_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], 
     RowBox[{"n", "-", "1"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "i", "]"}], "[", 
         RowBox[{"[", "k", "]"}], "]"}], "-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "[", "k", "]"}], "+", 
          RowBox[{
           RowBox[{"b", "[", "k", "]"}], 
           RowBox[{"(", 
            RowBox[{"x", "-", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"c", "[", "k", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", 
              RowBox[{
               RowBox[{"x", "[", "i", "]"}], "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"d", "[", "k", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", 
              RowBox[{
               RowBox[{"x", "[", "i", "]"}], "[", 
               RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "[", 
          RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}], "2"]}], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "i", "]"}], "[", 
        RowBox[{"[", "n", "]"}], "]"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", "[", 
          RowBox[{"n", "-", "1"}], "]"}], "+", 
         RowBox[{
          RowBox[{"b", "[", 
           RowBox[{"n", "-", "1"}], "]"}], 
          RowBox[{"(", 
           RowBox[{"x", "-", 
            RowBox[{
             RowBox[{"x", "[", "i", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"n", "-", "1"}], "]"}], "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"c", "[", 
           RowBox[{"n", "-", "1"}], "]"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"n", "-", "1"}], "]"}], "]"}]}], ")"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"n", "-", "1"}], "]"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", 
             RowBox[{
              RowBox[{"x", "[", "i", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"n", "-", "1"}], "]"}], "]"}]}], ")"}], "3"]}]}], 
        ")"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "[", 
         RowBox[{"[", "n", "]"}], "]"}]}], "}"}]}], ")"}], "2"], "+", 
   "\[IndentingNewLine]", 
   RowBox[{"lambda", "*", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "1"}], 
      RowBox[{"n", "-", "1"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"c", "[", "k", "]"}]}], "+", 
             RowBox[{"6", 
              RowBox[{"d", "[", "k", "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{
                  RowBox[{"x", "[", "i", "]"}], "[", 
                  RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "1"]}]}], ")"}], 
           "3"], 
          RowBox[{"3", "*", "6", 
           RowBox[{"d", "[", "k", "]"}]}]], "/.", 
         RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{
            RowBox[{"x", "[", "i", "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"k", "+", "1"}], "]"}], "]"}]}], "}"}]}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"c", "[", "k", "]"}]}], "+", 
             RowBox[{"6", 
              RowBox[{"d", "[", "k", "]"}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{
                  RowBox[{"x", "[", "i", "]"}], "[", 
                  RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "1"]}]}], ")"}], 
           "3"], 
          RowBox[{"3", "*", "6", 
           RowBox[{"d", "[", "k", "]"}]}]], "/.", 
         RowBox[{"{", 
          RowBox[{"x", "\[Rule]", 
           RowBox[{
            RowBox[{"x", "[", "i", "]"}], "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], "}"}]}], ")"}]}], 
      ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vars", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "[", "k", "]"}], ",", 
        RowBox[{"b", "[", "k", "]"}], ",", 
        RowBox[{"c", "[", "k", "]"}], ",", 
        RowBox[{"d", "[", "k", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"min", ",", "pw"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"min", "=", 
       RowBox[{"NMinimize", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"objective", "[", "lambda", "]"}], ",", "constraints"}], 
          "}"}], ",", "vars"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pw", "=", 
       RowBox[{"Piecewise", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", "[", "k", "]"}], "+", 
               RowBox[{
                RowBox[{"b", "[", "k", "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", 
                  RowBox[{
                   RowBox[{"x", "[", "i", "]"}], "[", 
                   RowBox[{"[", "k", "]"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"c", "[", "k", "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"d", "[", "k", "]"}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   RowBox[{
                    RowBox[{"x", "[", "i", "]"}], "[", 
                    RowBox[{"[", "k", "]"}], "]"}]}], ")"}], "3"]}]}], ")"}], 
             "/.", 
             RowBox[{
              RowBox[{"Partition", "[", 
               RowBox[{
                RowBox[{"Last", "[", "min", "]"}], ",", "4"}], "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}]}], ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"x", "[", "i", "]"}], "[", 
                RowBox[{"[", "k", "]"}], "]"}], "\[LessEqual]", "x"}], "&&", 
              RowBox[{"x", "\[LessEqual]", 
               RowBox[{
                RowBox[{"x", "[", "i", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{"k", "+", "1"}], "]"}], "]"}]}]}], ")"}]}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", 
            RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lambda", ",", "1", ",", "\"\<\[Lambda]\>\""}], "}"}], ",", "0",
      ",", "100", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[""], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Lineare Ausgleichsrechnung (Linear Least-Squares) \[RightArrow] {",
 StyleBox["Fit, FindFit",
  FontFamily->"Courier New"],
 "}"
}], "Section",
 CellChangeTimes->{3.49303046119446*^9}],

Cell[TextData[{
 "Basis polynomials {1, ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"x", "-", 
     SubscriptBox["\[Mu]", "i"]}], 
    SubscriptBox["\[Sigma]", "i"]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", 
       SubscriptBox["\[Mu]", "i"]}], 
      SubscriptBox["\[Sigma]", "i"]], ")"}], "2"], TraditionalForm]]],
 ", \[CenterEllipsis] , ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", 
       SubscriptBox["\[Mu]", "i"]}], 
      SubscriptBox["\[Sigma]", "i"]], ")"}], "n"], TraditionalForm]]],
 "}. The parameters ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Mu]", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "i"], TraditionalForm]]],
 ", respectively, denote the empirical mean and standard deviation of the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-data sets. Using these transformations improves numerical stability when \
using higher polynomial degrees."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Anwendung von ",
 StyleBox["Fit",
  FontFamily->"Courier New"],
 " und Integration"
}], "Subsection"],

Cell[TextData[{
 "A least-squares polynomial or another best fitting curve may be found by ",
 StyleBox["Mathematicas ",
  FontSlant->"Italic"],
 "command ",
 StyleBox["Fit",
  FontFamily->"Courier New"],
 " or ",
 StyleBox["FindFit",
  FontFamily->"Courier New"],
 " (the latter is appropriate for non-linear models). The next commands show \
how to compute least-squares polynomials of maximal degree ",
 StyleBox["n",
  FontSlant->"Italic"],
 " in the shifted and scaled basis polynomials {1, ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"x", "-", 
     SubscriptBox["\[Mu]", "i"]}], 
    SubscriptBox["\[Sigma]", "i"]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", 
       SubscriptBox["\[Mu]", "i"]}], 
      SubscriptBox["\[Sigma]", "i"]], ")"}], "2"], TraditionalForm]]],
 ", \[CenterEllipsis] , ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", 
       SubscriptBox["\[Mu]", "i"]}], 
      SubscriptBox["\[Sigma]", "i"]], ")"}], "n"], TraditionalForm]]],
 "}. The parameters ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Mu]", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "i"], TraditionalForm]]],
 ", respectively, denote the empirical mean and standard deviation of the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-data sets. Using these transformations improves numerical stability when \
using higher polynomial degrees."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis1", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"x", "-", 
        RowBox[{"Mean", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
          RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]}], 
       RowBox[{"StandardDeviation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
         RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"polybasis1", "[", 
  RowBox[{"8", ",", "5"}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"degree", "=", "16"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"leastsquarepoly", "[", "i", "]"}], "=", 
    RowBox[{"Fit", "[", 
     RowBox[{
      RowBox[{"durchfluss", "[", "i", "]"}], ",", 
      RowBox[{"polybasis1", "[", 
       RowBox[{"degree", ",", "i"}], "]"}], ",", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"leastsquarepoly", "[", "5", "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"HornerForm", "@", 
       RowBox[{"leastsquarepoly", "[", "i", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "700"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "i", "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{3.559867095176938*^9}],

Cell[TextData[{
 "The accumulated flow datas are approximated by integration of least-squares \
polynomials. The results are normalized and stored in ",
 StyleBox["HornerForm.",
  FontFamily->"Courier New"]
}], "Text"],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"leastsquarepolyacc", "[", "i", "]"}], "=", 
     RowBox[{"HornerForm", "@", 
      RowBox[{"(", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{"leastsquarepoly", "[", "i", "]"}], ",", "x"}], "]"}], 
       ")"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"leastsquarepolyacc", "[", "i", "]"}], "=", 
     RowBox[{
      RowBox[{"leastsquarepolyacc", "[", "i", "]"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"leastsquarepolyacc", "[", "i", "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{"x", "\[Rule]", "1.7818"}], "}"}]}], ")"}]}]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"leastsquarepolyacc", "[", "i", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Hue", "[", 
      RowBox[{"i", "/", "5"}], "]"}]}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{3.5598671157689743`*^9}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"leastsquarepolyacc", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Hue", "[", 
       RowBox[{"i", "/", "5"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.523871784453125*^9, 3.523871786859375*^9}, 
   3.5598671263769927`*^9}],

Cell[TextData[{
 "The next ",
 StyleBox["GraphicsGrid",
  FontFamily->"Courier New"],
 " shows all flow data together with accumulated (integrated) data."
}], "Text"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"durchflussplot", "[", "i", "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"leastsquarepoly", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Gray", ",", "Thin"}], "}"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"leastsquarepolyacc", "[", "i", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"Hue", "[", 
           RowBox[{"i", "/", "5"}], "]"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"\"\<F\[UDoubleDot]llstand \>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<F\[UDoubleDot]llzeit sec\>\"", ",", " ", 
            "\"\<\!\(\*SuperscriptBox[\(cm\), \(3\)]\)\>\""}], "}"}]}]}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]], "Input",
 CellChangeTimes->{3.52387179015625*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 StyleBox[" und Normalgleichungen ",
  FontFamily->"Arial"],
 "\[RightArrow] {",
 StyleBox["DesignMatrix, LinearSolve",
  FontFamily->"Courier New"],
 "}"
}], "Subsection",
 CellChangeTimes->{
  3.4930304690071096`*^9, {3.5604757250852056`*^9, 3.56047573358722*^9}, {
   3.5604765164901953`*^9, 3.5604765214822044`*^9}}],

Cell[TextData[{
 "The ",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 " for the numerical  data and the polynomial basis:"
}], "Text",
 CellChangeTimes->{{3.5604757425260363`*^9, 3.5604757694204836`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"1.7818", ",", "11.14"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", "x", ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4989782570625*^9, 3.498978258140625*^9}, 
   3.5604758030541425`*^9, {3.560475906887925*^9, 3.56047591565514*^9}, 
   3.560475974592044*^9}],

Cell[BoxData[
 RowBox[{"polybasis", "[", 
  RowBox[{"16", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.5604759301943655`*^9, 3.560475937229978*^9}, {
  3.560475998054485*^9, 3.560476003452094*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Shifted", " ", "and", " ", "scaled", " ", "basis", " ", "polynomials", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", " ", 
      FormBox[
       FractionBox[
        RowBox[{"x", "-", 
         SubscriptBox["\[Mu]", "i"]}], 
        SubscriptBox["\[Sigma]", "i"]],
       TraditionalForm], ",", " ", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"x", "-", 
           SubscriptBox["\[Mu]", "i"]}], 
          SubscriptBox["\[Sigma]", "i"]], ")"}], "2"],
       TraditionalForm], ",", " ", "\[CenterEllipsis]", " ", ",", " ", 
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"x", "-", 
           SubscriptBox["\[Mu]", "i"]}], 
          SubscriptBox["\[Sigma]", "i"]], ")"}], "n"],
       TraditionalForm]}], "}"}], ".", " ", "The"}], " ", "parameters", " ", 
   FormBox[
    SubscriptBox["\[Mu]", "i"],
    TraditionalForm], " ", "and", " ", 
   FormBox[
    SubscriptBox["\[Sigma]", "i"],
    TraditionalForm]}], ",", " ", "respectively", ",", " ", 
  RowBox[{
   RowBox[{
   "denote", " ", "the", " ", "empirical", " ", "mean", " ", "and", " ", 
    "standard", " ", "deviation", " ", "of", " ", "the", " ", 
    StyleBox["x",
     FontSlant->"Italic"]}], "-", 
   RowBox[{"data", " ", 
    RowBox[{"sets", ".", " ", "Using"}], " ", "these", " ", "transformations",
     " ", "improves", " ", "numerical", " ", "stability", " ", "when", " ", 
    "using", " ", "higher", " ", "polynomial", " ", 
    RowBox[{"degrees", "."}]}]}]}]], "Text",
 CellChangeTimes->{{3.5604758462818184`*^9, 3.56047585869944*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis1", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"x", "-", 
        RowBox[{"Mean", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
          RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]}], 
       RowBox[{"StandardDeviation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
         RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.560475885437887*^9, 3.560476008272503*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"degree", "=", "4"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Maximalgrad", " ", "der", " ", "Basispolynome"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"polybasis", "[", 
      RowBox[{"degree", ",", "m"}], "]"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "dm", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "//", "MatrixForm"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.498978225640625*^9, 3.498978268234375*^9, {3.4989786298125*^9, 
   3.4989786335*^9}, {3.5598673610482054`*^9, 3.559867366180614*^9}, {
   3.56047604093896*^9, 3.5604761197502985`*^9}, 3.560476544507845*^9, 
   3.5604766100903597`*^9, {3.5604770124462667`*^9, 3.5604770626939545`*^9}}],

Cell["The normal matrix ... ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"durchfluss", "[", "m", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.560477034411105*^9, 3.5604770703847685`*^9}}],

Cell[BoxData[
 RowBox[{"as", "=", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], ",", 
    RowBox[{
     RowBox[{"Transpose", "[", "dm", "]"}], ".", "y"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5604762242236824`*^9, 3.560476266952157*^9}}],

Cell[BoxData[
 RowBox[{"as", ".", 
  RowBox[{"polybasis", "[", 
   RowBox[{"4", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559867467393592*^9, 3.559867468345194*^9}, {
  3.5604762871385927`*^9, 3.5604762899777975`*^9}, {3.5604765745534973`*^9, 
  3.560476624301985*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"as", ".", 
       RowBox[{"polybasis", "[", 
        RowBox[{"4", ",", "5"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "700"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "m", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.498978721328125*^9, 3.498978734421875*^9}, {
   3.49897887653125*^9, 3.498978930578125*^9}, {3.5604763348122764`*^9, 
   3.560476338681083*^9}, 3.5604765781571035`*^9, 3.5604766282955923`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"degree", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"leastsquarespoly1", "=", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"durchfluss", "[", "m", "]"}], ",", 
    RowBox[{"polybasis1", "[", 
     RowBox[{"degree", ",", "m"}], "]"}], ",", "x"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5604764154800177`*^9, 3.560476428818042*^9}, {
  3.56047709400321*^9, 3.5604770995880194`*^9}}],

Cell[BoxData[
 RowBox[{"%", "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.5604771041900277`*^9, 3.5604771068732324`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{"leastsquarespoly1", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "700"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "m", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.560477133455679*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 StyleBox[", QR-Zerlegung ",
  FontFamily->"Arial"],
 "\[RightArrow] {",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["QRDecomposition",
  FontFamily->"Courier New"],
 "}"
}], "Subsection",
 CellChangeTimes->{3.4930304639913883`*^9}],

Cell[TextData[{
 "The ",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 " for the numerical data and the corresponding normalized basis polynomials:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis1", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"x", "-", 
        RowBox[{"Mean", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
          RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]}], 
       RowBox[{"StandardDeviation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
         RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"degree", "=", "16"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Maximalgrad", " ", "der", " ", "Basispolynome"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"polybasis1", "[", 
      RowBox[{"degree", ",", "m"}], "]"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "//", "MatrixForm"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5598671757198796`*^9, 3.559867210492341*^9}}],

Cell["The normal matrix ... ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{3.5598671509938364`*^9}],

Cell[TextData[{
 "... and the design matrix followed by ",
 StyleBox["QRDecomposition",
  FontFamily->"Courier New"],
 " :"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", ",", "r"}], "}"}], "=", 
   RowBox[{"QRDecomposition", "[", "dm", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5598671641290593`*^9, 3.5598671681538663`*^9}}],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " q is row-orthogonal and r is upper right square triangle. With these \
matrices we can solve for the coefficients of the least-squares approximating \
polynomial. The coefficients refer to the basis."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"durchfluss", "[", "m", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{"LinearSolve", "[", 
   RowBox[{"r", ",", 
    RowBox[{"q", ".", "y"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"a", ".", 
  RowBox[{"polybasis1", "[", 
   RowBox[{"degree", ",", "m"}], "]"}]}]], "Input"],

Cell[TextData[{
 "The results by ",
 StyleBox["QRDecomposition",
  FontFamily->"Courier New"],
 " do not differ from those of ",
 StyleBox["Mathematicas",
  FontSlant->"Italic"],
 " ",
 StyleBox["Fit",
  FontFamily->"Courier New"],
 " Command."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"degree", "=", "16"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"leastsquaresbasispoly", "=", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"durchfluss", "[", "m", "]"}], ",", 
    RowBox[{"polybasis1", "[", 
     RowBox[{"degree", ",", "m"}], "]"}], ",", "x"}], "]"}]}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 StyleBox[", SVD-Zerlegung ",
  FontFamily->"Arial"],
 "\[RightArrow] {",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["SingularValueDecomposition",
  FontFamily->"Courier New"],
 "}"
}], "Subsection",
 CellChangeTimes->{3.493030466569563*^9}],

Cell[TextData[{
 "The ",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 " for the numerical data and the corresponding Newton-Basis:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", "x", ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4989782570625*^9, 3.498978258140625*^9}, 
   3.5604758030541425`*^9, {3.560475906887925*^9, 3.56047591565514*^9}, 
   3.560475974592044*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis1", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"x", "-", 
        RowBox[{"Mean", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
          RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]}], 
       RowBox[{"StandardDeviation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
         RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis1", "[", 
   RowBox[{"degree", ",", "i"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.560476743720195*^9, 3.560476753189411*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"degree", "=", "4"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Maximalgrad", " ", "der", " ", "Basispolynome"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"polybasis", "[", 
      RowBox[{"degree", ",", "m"}], "]"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "//", "MatrixForm"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5604767561534166`*^9, 3.560476766777035*^9}, {
   3.560476895945262*^9, 3.5604769001728697`*^9}, 3.5604769963158383`*^9, {
   3.560477156309719*^9, 3.560477162814931*^9}, 3.5604773413728447`*^9}],

Cell["The normal matrix ... ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", "MatrixForm"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5604769029964743`*^9, 3.5604769075672827`*^9}}],

Cell[TextData[{
 "... and the design matrix followed by ",
 StyleBox["SingularValueDecomposition",
  FontFamily->"Courier New"],
 " :"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"u", ",", "d", ",", "v"}], "}"}], "=", 
   RowBox[{"SingularValueDecomposition", "[", 
    RowBox[{"dm", ",", 
     RowBox[{"degree", "+", "1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.560477169195342*^9, 3.5604771736881495`*^9}, {
  3.5605133764606786`*^9, 3.560513376819479*^9}, {3.560513527562544*^9, 
  3.560513529403347*^9}}],

Cell["\<\
The matrices u and v are orthogonal, d is diagonal. 
With these matrices we can solve for the coefficients of the least-squares \
approximating polynomial. The coefficients refer to the Newton-basis.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Dimensions", "/@", 
  RowBox[{"{", 
   RowBox[{"u", ",", "d", ",", "v"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5605133962727137`*^9, 3.5605134338375797`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"durchfluss", "[", "m", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.560476933588128*^9, {3.5605132243282113`*^9, 3.560513224671412*^9}}],

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{"v", ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Transpose", "[", "u", "]"}], ".", "y"}], ")"}], "/", 
     RowBox[{"Diagonal", "[", "d", "]"}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"a", ".", 
  RowBox[{"polybasis", "[", 
   RowBox[{"degree", ",", "m"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.560476949000955*^9, {3.5604771853413706`*^9, 3.560477185856171*^9}, 
   3.5604773524956636`*^9}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"a", ".", 
       RowBox[{"polybasis", "[", 
        RowBox[{"4", ",", "m"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "700"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "m", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.498978721328125*^9, 3.498978734421875*^9}, {
   3.49897887653125*^9, 3.498978930578125*^9}, {3.5604763348122764`*^9, 
   3.560476338681083*^9}, 3.5604765781571035`*^9, 3.5604766282955923`*^9, 
   3.5604773621520805`*^9, 3.5605132414882417`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"degree", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"leastsquarespoly1", "=", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"durchfluss", "[", "m", "]"}], ",", 
    RowBox[{"polybasis", "[", 
     RowBox[{"degree", ",", "m"}], "]"}], ",", "x"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.560476967096987*^9, 3.5604769764414034`*^9}, 
   3.560477191893382*^9, 3.5604773734309006`*^9, {3.560513250848258*^9, 
   3.5605132511602583`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"as", ".", 
       RowBox[{"polybasis", "[", 
        RowBox[{"4", ",", "5"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "700"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "m", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.498978721328125*^9, 3.498978734421875*^9}, {
   3.49897887653125*^9, 3.498978930578125*^9}, {3.5604763348122764`*^9, 
   3.560476338681083*^9}, 3.5604765781571035`*^9, 3.5604766282955923`*^9, 
   3.5604772629359064`*^9, 3.560477382182516*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Chebyshev Least-Squares ",
  FontFamily->"Arial"],
 "\[RightArrow] {",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["ChebyshevT",
  FontFamily->"Courier New"],
 "}"
}], "Subsection",
 CellChangeTimes->{3.4930304690071096`*^9}],

Cell[TextData[{
 "The ",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 " for the numerical Chebyshev data and the corresponding Chebyshev-Basis:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"1.7818", ",", "11.14"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"chebbasis", "[", 
   RowBox[{"k_", ",", "x_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"ChebyshevT", "[", 
     RowBox[{"j", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", 
        FractionBox[
         RowBox[{"x", "-", "a"}], 
         RowBox[{"b", "-", "a"}]]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "k"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4989782570625*^9, 3.498978258140625*^9}}],

Cell[BoxData[
 RowBox[{"chebbasis", "[", 
  RowBox[{"4", ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.5598673476945815`*^9, 3.5598673482093825`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"degree", "=", "4"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Maximalgrad", " ", "der", " ", "Basispolynome"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"chebbasis", "[", 
      RowBox[{"degree", ",", "x"}], "]"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "//", "MatrixForm"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.498978225640625*^9, 3.498978268234375*^9, {3.4989786298125*^9, 
   3.4989786335*^9}, {3.5598673610482054`*^9, 3.559867366180614*^9}}],

Cell["The normal matrix ... ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"durchfluss", "[", "m", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"as", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Transpose", "[", "dm", "]"}], ".", "y"}], ")"}], "/", 
   RowBox[{"Diagonal", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"as", ".", 
  RowBox[{"chebbasis", "[", 
   RowBox[{"4", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.559867467393592*^9, 3.559867468345194*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"degree", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"leastsquareschebpoly", "[", "m", "]"}], "=", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"durchfluss", "[", "m", "]"}], ",", 
    RowBox[{"chebbasis", "[", 
     RowBox[{"degree", ",", "x"}], "]"}], ",", "x"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.498978643671875*^9, 3.49897864428125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"HornerForm", "@", 
       RowBox[{"leastsquareschebpoly", "[", "m", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "12"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "100"}], ",", "700"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"durchflussplot", "[", "m", "]"}]}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.498978721328125*^9, 3.498978734421875*^9}, {
  3.49897887653125*^9, 3.498978930578125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["*Unstabile Orthogonalisierung mit modifiziertem \
Gram-Schmidt-Verfahren",
 FontFamily->"Arial"]], "Subsection",
 CellChangeTimes->{3.523871989765625*^9},
 FontColor->GrayLevel[0.5]],

Cell[TextData[{
 "The ",
 StyleBox["DesignMatrix",
  FontFamily->"Courier New"],
 " for the numerical data and the corresponding Newton-Basis:"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"newtonpoly", "[", 
   RowBox[{"k_", ",", "var_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Product", "[", 
    RowBox[{
     RowBox[{"var", "-", 
      RowBox[{"x", "[", "i", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"k", "-", "1"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "i", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"durchfluss", "[", "m", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"i", "+", "1"}], ",", "1"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "k"}], "}"}]}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"newtonpoly", "[", 
  RowBox[{"16", ",", "x"}], "]"}]], "Input"],

Cell[TextData[{
 "\nTo avoid normalization a modified version of the Gram-Schmidt procedure \
only using ",
 StyleBox["Projection",
  FontFamily->"Courier New"],
 "s is defined:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"myGramSchmidt", "[", 
   RowBox[{"vecs_", ",", "ip___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ovecs", "=", "vecs"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ovecs", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "-=", 
        RowBox[{"Projection", "[", 
         RowBox[{
          RowBox[{"ovecs", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"ovecs", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", "ip"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{"Length", "[", "vecs", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"i", "-", "1"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "ovecs"}]}], "]"}]}]], "Input",
 Background->RGBColor[
  0.9411764705882353, 0.9411764705882353, 0.9411764705882353],
 CellID->7542679],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"degree", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orthonewton2", "=", 
   RowBox[{"myGramSchmidt", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"newtonpoly", "[", 
        RowBox[{"k", ",", "x"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "degree"}], "}"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#1", "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"durchfluss", "[", "m", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}], "*", " ", 
         RowBox[{"(", " ", 
          RowBox[{"#2", "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"durchfluss", "[", "m", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}], 
      "&"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"orthonewton2", ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"HornerForm", "/@", "orthonewton2"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\

The modified Gram-Schmidt procedure is numerically not stable. The matrix of \
the normal equations is not diagonal.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", "MatrixForm"}], 
  ";"}]], "Input"],

Cell[TextData[{
 "The next commands show better numeric stability for the shifted and scaled \
basis polynomials {1, ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"x", "-", 
     SubscriptBox["\[Mu]", "i"]}], 
    SubscriptBox["\[Sigma]", "i"]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", 
       SubscriptBox["\[Mu]", "i"]}], 
      SubscriptBox["\[Sigma]", "i"]], ")"}], "2"], TraditionalForm]]],
 ", \[CenterEllipsis] , ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"x", "-", 
       SubscriptBox["\[Mu]", "i"]}], 
      SubscriptBox["\[Sigma]", "i"]], ")"}], "n"], TraditionalForm]]],
 "} together with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "s ",
 StyleBox["Orthogonalize",
  FontFamily->"Courier New"],
 StyleBox[" and ",
  FontFamily->"Times New Roman"],
 StyleBox["HornerForm.",
  FontFamily->"Courier New"],
 " The parameters ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Mu]", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "i"], TraditionalForm]]],
 ", respectively, denote the empirical mean and standard deviation of the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-data sets. Using these transformations improves numerical stability when \
using higher polynomial degrees. ",
 StyleBox["Mathematicas",
  FontSlant->"Italic"],
 " internal command ",
 StyleBox["Orthogonalize",
  FontFamily->"Courier New"],
 " is more stable. The most stable and fastest Householder method is not \
applicable for non-numeric data."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polybasis1", "[", 
   RowBox[{"n_", ",", "i_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"x", "-", 
        RowBox[{"Mean", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
          RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]}], 
       RowBox[{"StandardDeviation", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "&"}], "/@", 
         RowBox[{"durchfluss", "[", "i", "]"}]}], "]"}]], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"degree", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ortho1", "=", 
   RowBox[{"myGramSchmidt", "[", 
    RowBox[{
     RowBox[{"HornerForm", "/@", 
      RowBox[{"polybasis1", "[", 
       RowBox[{"degree", ",", "m"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#1", "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"durchfluss", "[", "m", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}], "*", " ", 
         RowBox[{"(", " ", 
          RowBox[{"#2", "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"durchfluss", "[", "m", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}], 
      "&"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"HornerForm", "/@", "ortho1"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{3.523872008109375*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "5"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Durchflussnr", "."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"degree", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ortho2", "=", 
   RowBox[{"Orthogonalize", "[", 
    RowBox[{
     RowBox[{"HornerForm", "/@", 
      RowBox[{"polybasis1", "[", 
       RowBox[{"degree", ",", "m"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#1", "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"durchfluss", "[", "m", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}], "*", " ", 
         RowBox[{"(", " ", 
          RowBox[{"#2", "/.", 
           RowBox[{"{", 
            RowBox[{"x", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"durchfluss", "[", "m", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"durchfluss", "[", "m", "]"}], "]"}]}], "}"}]}], "]"}], 
      "&"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.5238720124375*^9, 3.52387204284375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dm", "=", 
   RowBox[{"DesignMatrix", "[", 
    RowBox[{
     RowBox[{"durchfluss", "[", "m", "]"}], ",", 
     RowBox[{"HornerForm", "/@", "ortho2"}], ",", "x", ",", 
     RowBox[{"IncludeConstantBasis", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.52387202165625*^9, 3.5238720479375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Transpose", "[", "dm", "]"}], ".", "dm"}], "//", "MatrixForm"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.52387203165625*^9, 3.523872050609375*^9}}],

Cell[BoxData[""], "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowGroupOpener->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 50, 0, 83, "Title"],
Cell[620, 24, 318, 7, 133, "Subtitle"],
Cell[CellGroupData[{
Cell[963, 35, 60, 0, 71, "Section"],
Cell[1026, 37, 930, 18, 130, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1993, 60, 71, 0, 41, "Section"],
Cell[2067, 62, 394, 9, 29, "Text"],
Cell[2464, 73, 104, 2, 31, "Input"],
Cell[2571, 77, 187, 4, 29, "Text"],
Cell[2761, 83, 525, 10, 31, "Input"],
Cell[3289, 95, 620, 16, 52, "Input"],
Cell[3912, 113, 732, 22, 31, "Input"],
Cell[4647, 137, 57, 0, 29, "Text"],
Cell[4707, 139, 1025, 27, 120, "Input"],
Cell[5735, 168, 253, 4, 29, "Text"],
Cell[5991, 174, 518, 13, 31, "Input"],
Cell[6512, 189, 406, 12, 29, "Text"],
Cell[6921, 203, 511, 16, 31, "Input"],
Cell[7435, 221, 738, 19, 31, "Input"],
Cell[8176, 242, 183, 3, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8396, 250, 160, 5, 42, "Section"],
Cell[8559, 257, 550, 12, 47, "Text"],
Cell[9112, 271, 370, 10, 52, "Input"],
Cell[9485, 283, 443, 11, 47, "Text"],
Cell[9931, 296, 195, 4, 31, "Input"],
Cell[10129, 302, 222, 5, 31, "Input"],
Cell[10354, 309, 496, 8, 47, "Text"],
Cell[10853, 319, 638, 16, 52, "Input"],
Cell[11494, 337, 315, 8, 52, "Input"],
Cell[11812, 347, 150, 3, 29, "Text"],
Cell[11965, 352, 1051, 28, 55, "Input"],
Cell[CellGroupData[{
Cell[13041, 384, 197, 4, 36, "Subsection"],
Cell[13241, 390, 597, 16, 47, "Text"],
Cell[13841, 408, 1178, 37, 92, "Input"],
Cell[15022, 447, 227, 7, 31, "Input"],
Cell[15252, 456, 837, 23, 55, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[16126, 484, 120, 2, 28, "Subsection"],
Cell[16249, 488, 490, 8, 47, "Text"],
Cell[16742, 498, 752, 22, 52, "Input"],
Cell[17497, 522, 221, 4, 29, "Text"],
Cell[17721, 528, 476, 12, 52, "Input"],
Cell[18200, 542, 563, 16, 52, "Input"],
Cell[18766, 560, 226, 4, 29, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[19041, 570, 120, 5, 42, "Section"],
Cell[CellGroupData[{
Cell[19186, 579, 132, 5, 37, "Subsection"],
Cell[19321, 586, 607, 15, 47, "Text"],
Cell[19931, 603, 425, 11, 31, "Input"],
Cell[20359, 616, 394, 11, 29, "Text"],
Cell[20756, 629, 270, 7, 31, "Input"],
Cell[21029, 638, 114, 3, 31, "Input"],
Cell[21146, 643, 670, 17, 52, "Input"],
Cell[21819, 662, 126, 3, 29, "Text"],
Cell[21948, 667, 156, 5, 31, "Input"],
Cell[22107, 674, 449, 13, 92, "Input"],
Cell[22559, 689, 110, 3, 29, "Text"],
Cell[22672, 694, 488, 13, 52, "Input"],
Cell[23163, 709, 753, 20, 31, "Input"],
Cell[23919, 731, 166, 5, 29, "Text"],
Cell[24088, 738, 1916, 44, 99, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[26041, 787, 60, 0, 28, "Subsection"],
Cell[26104, 789, 641, 28, 29, "Text"],
Cell[26748, 819, 2473, 74, 132, "Input"],
Cell[29224, 895, 26, 0, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[29287, 900, 223, 4, 28, "Subsection"],
Cell[29513, 906, 1122, 36, 112, "Input"],
Cell[30638, 944, 9548, 254, 187, "Input"],
Cell[40189, 1200, 4926, 149, 125, "Input"],
Cell[45118, 1351, 465, 14, 31, "Input"],
Cell[45586, 1367, 2832, 76, 120, "Input"],
Cell[48421, 1445, 26, 0, 31, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[48496, 1451, 202, 6, 42, "Section"],
Cell[48701, 1459, 1093, 39, 64, "Text"],
Cell[CellGroupData[{
Cell[49819, 1502, 119, 5, 37, "Subsection"],
Cell[49941, 1509, 1549, 52, 82, "Text"],
Cell[51493, 1563, 760, 23, 49, "Input"],
Cell[52256, 1588, 86, 2, 31, "Input"],
Cell[52345, 1592, 464, 13, 52, "Input"],
Cell[52812, 1607, 68, 1, 31, "Input"],
Cell[52883, 1610, 604, 17, 52, "Input"],
Cell[53490, 1629, 218, 5, 29, "Text"],
Cell[53711, 1636, 821, 23, 92, "Input"],
Cell[54535, 1661, 444, 12, 52, "Input"],
Cell[54982, 1675, 730, 20, 31, "Input"],
Cell[55715, 1697, 166, 5, 29, "Text"],
Cell[55884, 1704, 1546, 39, 99, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[57467, 1748, 392, 12, 29, "Subsection"],
Cell[57862, 1762, 216, 6, 29, "Text"],
Cell[58081, 1770, 174, 6, 31, "Input"],
Cell[58258, 1778, 444, 12, 33, "Input"],
Cell[58705, 1792, 203, 4, 31, "Input"],
Cell[58911, 1798, 1668, 46, 69, "Text"],
Cell[60582, 1846, 824, 24, 49, "Input"],
Cell[61409, 1872, 1127, 28, 112, "Input"],
Cell[62539, 1902, 38, 0, 29, "Text"],
Cell[62580, 1904, 124, 4, 31, "Input"],
Cell[62707, 1910, 467, 14, 31, "Input"],
Cell[63177, 1926, 311, 8, 31, "Input"],
Cell[63491, 1936, 280, 6, 31, "Input"],
Cell[63774, 1944, 722, 18, 31, "Input"],
Cell[64499, 1964, 431, 10, 52, "Input"],
Cell[64933, 1976, 127, 2, 31, "Input"],
Cell[65063, 1980, 467, 13, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[65567, 1998, 333, 13, 29, "Subsection"],
Cell[65903, 2013, 171, 5, 29, "Text"],
Cell[66077, 2020, 760, 23, 49, "Input"],
Cell[66840, 2045, 823, 23, 92, "Input"],
Cell[67666, 2070, 38, 0, 29, "Text"],
Cell[67707, 2072, 168, 5, 31, "Input"],
Cell[67878, 2079, 135, 5, 29, "Text"],
Cell[68016, 2086, 230, 6, 31, "Input"],
Cell[68249, 2094, 288, 7, 29, "Text"],
Cell[68540, 2103, 399, 13, 31, "Input"],
Cell[68942, 2118, 136, 4, 31, "Input"],
Cell[69081, 2124, 115, 3, 31, "Input"],
Cell[69199, 2129, 256, 11, 29, "Text"],
Cell[69458, 2142, 318, 8, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[69813, 2155, 343, 13, 29, "Subsection"],
Cell[70159, 2170, 155, 5, 29, "Text"],
Cell[70317, 2177, 444, 12, 33, "Input"],
Cell[70764, 2191, 760, 23, 49, "Input"],
Cell[71527, 2216, 176, 4, 31, "Input"],
Cell[71706, 2222, 971, 25, 92, "Input"],
Cell[72680, 2249, 38, 0, 29, "Text"],
Cell[72721, 2251, 214, 6, 31, "Input"],
Cell[72938, 2259, 146, 5, 29, "Text"],
Cell[73087, 2266, 405, 10, 31, "Input"],
Cell[73495, 2278, 223, 4, 47, "Text"],
Cell[73721, 2284, 186, 4, 31, "Input"],
Cell[73910, 2290, 492, 15, 31, "Input"],
Cell[74405, 2307, 253, 8, 31, "Input"],
Cell[74661, 2317, 235, 6, 31, "Input"],
Cell[74899, 2325, 773, 19, 31, "Input"],
Cell[75675, 2346, 482, 11, 52, "Input"],
Cell[76160, 2359, 772, 19, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[76969, 2383, 281, 11, 29, "Subsection"],
Cell[77253, 2396, 168, 5, 29, "Text"],
Cell[77424, 2403, 174, 6, 31, "Input"],
Cell[77601, 2411, 518, 16, 45, "Input"],
Cell[78122, 2429, 155, 3, 31, "Input"],
Cell[78280, 2434, 911, 25, 92, "Input"],
Cell[79194, 2461, 38, 0, 29, "Text"],
Cell[79235, 2463, 124, 4, 31, "Input"],
Cell[79362, 2469, 399, 13, 31, "Input"],
Cell[79764, 2484, 264, 8, 31, "Input"],
Cell[80031, 2494, 176, 4, 31, "Input"],
Cell[80210, 2500, 408, 10, 52, "Input"],
Cell[80621, 2512, 681, 18, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[81339, 2535, 206, 4, 28, "Subsection"],
Cell[81548, 2541, 155, 5, 29, "Text"],
Cell[81706, 2548, 855, 27, 52, "Input"],
Cell[82564, 2577, 87, 2, 31, "Input"],
Cell[82654, 2581, 190, 6, 47, "Text"],
Cell[82847, 2589, 1023, 29, 88, "Input",
 CellID->7542679],
Cell[83873, 2620, 1534, 44, 92, "Input"],
Cell[85410, 2666, 55, 1, 31, "Input"],
Cell[85468, 2669, 298, 8, 31, "Input"],
Cell[85769, 2679, 141, 4, 47, "Text"],
Cell[85913, 2685, 144, 5, 31, "Input"],
Cell[86060, 2692, 1651, 57, 82, "Text"],
Cell[87714, 2751, 760, 23, 49, "Input"],
Cell[88477, 2776, 1433, 41, 72, "Input"],
Cell[89913, 2819, 292, 8, 31, "Input"],
Cell[90208, 2829, 166, 5, 31, "Input"],
Cell[90377, 2836, 1494, 42, 72, "Input"],
Cell[91874, 2880, 355, 9, 31, "Input"],
Cell[92232, 2891, 209, 6, 31, "Input"],
Cell[92444, 2899, 26, 0, 31, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
